#######################
PyDMTimePlot
#######################

.. autoclass:: pydm.widgets.timeplot.PyDMTimePlot
   :members:
   :show-inheritance:

#######################
TimePlotCurveItem
#######################

.. autoclass:: pydm.widgets.timeplot.TimePlotCurveItem
   :members:
   :show-inheritance:
